# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.8.1 Python SDK

    Pure Storage FlashBlade REST 1.8.1 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.8.1
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ArrayHttpPerformance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'read_dirs_per_sec': 'int',
        'write_dirs_per_sec': 'int',
        'read_files_per_sec': 'int',
        'write_files_per_sec': 'int',
        'others_per_sec': 'int',
        'usec_per_read_dir_op': 'int',
        'usec_per_write_dir_op': 'int',
        'usec_per_read_file_op': 'int',
        'usec_per_write_file_op': 'int',
        'usec_per_other_op': 'int',
        'time': 'int'
    }

    attribute_map = {
        'name': 'name',
        'read_dirs_per_sec': 'read_dirs_per_sec',
        'write_dirs_per_sec': 'write_dirs_per_sec',
        'read_files_per_sec': 'read_files_per_sec',
        'write_files_per_sec': 'write_files_per_sec',
        'others_per_sec': 'others_per_sec',
        'usec_per_read_dir_op': 'usec_per_read_dir_op',
        'usec_per_write_dir_op': 'usec_per_write_dir_op',
        'usec_per_read_file_op': 'usec_per_read_file_op',
        'usec_per_write_file_op': 'usec_per_write_file_op',
        'usec_per_other_op': 'usec_per_other_op',
        'time': 'time'
    }

    def __init__(self, name=None, read_dirs_per_sec=None, write_dirs_per_sec=None, read_files_per_sec=None, write_files_per_sec=None, others_per_sec=None, usec_per_read_dir_op=None, usec_per_write_dir_op=None, usec_per_read_file_op=None, usec_per_write_file_op=None, usec_per_other_op=None, time=None):  # noqa: E501
        """ArrayHttpPerformance - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._read_dirs_per_sec = None
        self._write_dirs_per_sec = None
        self._read_files_per_sec = None
        self._write_files_per_sec = None
        self._others_per_sec = None
        self._usec_per_read_dir_op = None
        self._usec_per_write_dir_op = None
        self._usec_per_read_file_op = None
        self._usec_per_write_file_op = None
        self._usec_per_other_op = None
        self._time = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if read_dirs_per_sec is not None:
            self.read_dirs_per_sec = read_dirs_per_sec
        if write_dirs_per_sec is not None:
            self.write_dirs_per_sec = write_dirs_per_sec
        if read_files_per_sec is not None:
            self.read_files_per_sec = read_files_per_sec
        if write_files_per_sec is not None:
            self.write_files_per_sec = write_files_per_sec
        if others_per_sec is not None:
            self.others_per_sec = others_per_sec
        if usec_per_read_dir_op is not None:
            self.usec_per_read_dir_op = usec_per_read_dir_op
        if usec_per_write_dir_op is not None:
            self.usec_per_write_dir_op = usec_per_write_dir_op
        if usec_per_read_file_op is not None:
            self.usec_per_read_file_op = usec_per_read_file_op
        if usec_per_write_file_op is not None:
            self.usec_per_write_file_op = usec_per_write_file_op
        if usec_per_other_op is not None:
            self.usec_per_other_op = usec_per_other_op
        if time is not None:
            self.time = time

    @property
    def name(self):
        """Gets the name of this ArrayHttpPerformance.  # noqa: E501

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :return: The name of this ArrayHttpPerformance.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ArrayHttpPerformance.

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :param name: The name of this ArrayHttpPerformance.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def read_dirs_per_sec(self):
        """Gets the read_dirs_per_sec of this ArrayHttpPerformance.  # noqa: E501

        Read directories requests processed per second  # noqa: E501

        :return: The read_dirs_per_sec of this ArrayHttpPerformance.  # noqa: E501
        :rtype: int
        """
        return self._read_dirs_per_sec

    @read_dirs_per_sec.setter
    def read_dirs_per_sec(self, read_dirs_per_sec):
        """Sets the read_dirs_per_sec of this ArrayHttpPerformance.

        Read directories requests processed per second  # noqa: E501

        :param read_dirs_per_sec: The read_dirs_per_sec of this ArrayHttpPerformance.  # noqa: E501
        :type: int
        """
        if read_dirs_per_sec is not None and read_dirs_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `read_dirs_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._read_dirs_per_sec = read_dirs_per_sec

    @property
    def write_dirs_per_sec(self):
        """Gets the write_dirs_per_sec of this ArrayHttpPerformance.  # noqa: E501

        Write directories requests processed per second  # noqa: E501

        :return: The write_dirs_per_sec of this ArrayHttpPerformance.  # noqa: E501
        :rtype: int
        """
        return self._write_dirs_per_sec

    @write_dirs_per_sec.setter
    def write_dirs_per_sec(self, write_dirs_per_sec):
        """Sets the write_dirs_per_sec of this ArrayHttpPerformance.

        Write directories requests processed per second  # noqa: E501

        :param write_dirs_per_sec: The write_dirs_per_sec of this ArrayHttpPerformance.  # noqa: E501
        :type: int
        """
        if write_dirs_per_sec is not None and write_dirs_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `write_dirs_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._write_dirs_per_sec = write_dirs_per_sec

    @property
    def read_files_per_sec(self):
        """Gets the read_files_per_sec of this ArrayHttpPerformance.  # noqa: E501

        Read files requests processed per second  # noqa: E501

        :return: The read_files_per_sec of this ArrayHttpPerformance.  # noqa: E501
        :rtype: int
        """
        return self._read_files_per_sec

    @read_files_per_sec.setter
    def read_files_per_sec(self, read_files_per_sec):
        """Sets the read_files_per_sec of this ArrayHttpPerformance.

        Read files requests processed per second  # noqa: E501

        :param read_files_per_sec: The read_files_per_sec of this ArrayHttpPerformance.  # noqa: E501
        :type: int
        """
        if read_files_per_sec is not None and read_files_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `read_files_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._read_files_per_sec = read_files_per_sec

    @property
    def write_files_per_sec(self):
        """Gets the write_files_per_sec of this ArrayHttpPerformance.  # noqa: E501

        Write files requests processed per second  # noqa: E501

        :return: The write_files_per_sec of this ArrayHttpPerformance.  # noqa: E501
        :rtype: int
        """
        return self._write_files_per_sec

    @write_files_per_sec.setter
    def write_files_per_sec(self, write_files_per_sec):
        """Sets the write_files_per_sec of this ArrayHttpPerformance.

        Write files requests processed per second  # noqa: E501

        :param write_files_per_sec: The write_files_per_sec of this ArrayHttpPerformance.  # noqa: E501
        :type: int
        """
        if write_files_per_sec is not None and write_files_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `write_files_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._write_files_per_sec = write_files_per_sec

    @property
    def others_per_sec(self):
        """Gets the others_per_sec of this ArrayHttpPerformance.  # noqa: E501

        Other operations processed per second  # noqa: E501

        :return: The others_per_sec of this ArrayHttpPerformance.  # noqa: E501
        :rtype: int
        """
        return self._others_per_sec

    @others_per_sec.setter
    def others_per_sec(self, others_per_sec):
        """Sets the others_per_sec of this ArrayHttpPerformance.

        Other operations processed per second  # noqa: E501

        :param others_per_sec: The others_per_sec of this ArrayHttpPerformance.  # noqa: E501
        :type: int
        """
        if others_per_sec is not None and others_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `others_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._others_per_sec = others_per_sec

    @property
    def usec_per_read_dir_op(self):
        """Gets the usec_per_read_dir_op of this ArrayHttpPerformance.  # noqa: E501

        Average time, measured in microseconds, that the array takes to process a read directory request  # noqa: E501

        :return: The usec_per_read_dir_op of this ArrayHttpPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_read_dir_op

    @usec_per_read_dir_op.setter
    def usec_per_read_dir_op(self, usec_per_read_dir_op):
        """Sets the usec_per_read_dir_op of this ArrayHttpPerformance.

        Average time, measured in microseconds, that the array takes to process a read directory request  # noqa: E501

        :param usec_per_read_dir_op: The usec_per_read_dir_op of this ArrayHttpPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_read_dir_op is not None and usec_per_read_dir_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_read_dir_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_read_dir_op = usec_per_read_dir_op

    @property
    def usec_per_write_dir_op(self):
        """Gets the usec_per_write_dir_op of this ArrayHttpPerformance.  # noqa: E501

        Average time, measured in microseconds, that the array takes to process a write directory request  # noqa: E501

        :return: The usec_per_write_dir_op of this ArrayHttpPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_write_dir_op

    @usec_per_write_dir_op.setter
    def usec_per_write_dir_op(self, usec_per_write_dir_op):
        """Sets the usec_per_write_dir_op of this ArrayHttpPerformance.

        Average time, measured in microseconds, that the array takes to process a write directory request  # noqa: E501

        :param usec_per_write_dir_op: The usec_per_write_dir_op of this ArrayHttpPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_write_dir_op is not None and usec_per_write_dir_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_write_dir_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_write_dir_op = usec_per_write_dir_op

    @property
    def usec_per_read_file_op(self):
        """Gets the usec_per_read_file_op of this ArrayHttpPerformance.  # noqa: E501

        Average time, measured in microseconds, that the array takes to process a read file request  # noqa: E501

        :return: The usec_per_read_file_op of this ArrayHttpPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_read_file_op

    @usec_per_read_file_op.setter
    def usec_per_read_file_op(self, usec_per_read_file_op):
        """Sets the usec_per_read_file_op of this ArrayHttpPerformance.

        Average time, measured in microseconds, that the array takes to process a read file request  # noqa: E501

        :param usec_per_read_file_op: The usec_per_read_file_op of this ArrayHttpPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_read_file_op is not None and usec_per_read_file_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_read_file_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_read_file_op = usec_per_read_file_op

    @property
    def usec_per_write_file_op(self):
        """Gets the usec_per_write_file_op of this ArrayHttpPerformance.  # noqa: E501

        Average time, measured in microseconds, that the array takes to process a write file request  # noqa: E501

        :return: The usec_per_write_file_op of this ArrayHttpPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_write_file_op

    @usec_per_write_file_op.setter
    def usec_per_write_file_op(self, usec_per_write_file_op):
        """Sets the usec_per_write_file_op of this ArrayHttpPerformance.

        Average time, measured in microseconds, that the array takes to process a write file request  # noqa: E501

        :param usec_per_write_file_op: The usec_per_write_file_op of this ArrayHttpPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_write_file_op is not None and usec_per_write_file_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_write_file_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_write_file_op = usec_per_write_file_op

    @property
    def usec_per_other_op(self):
        """Gets the usec_per_other_op of this ArrayHttpPerformance.  # noqa: E501

        Average time, measured in microseconds, that the array takes to process other operations  # noqa: E501

        :return: The usec_per_other_op of this ArrayHttpPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_other_op

    @usec_per_other_op.setter
    def usec_per_other_op(self, usec_per_other_op):
        """Sets the usec_per_other_op of this ArrayHttpPerformance.

        Average time, measured in microseconds, that the array takes to process other operations  # noqa: E501

        :param usec_per_other_op: The usec_per_other_op of this ArrayHttpPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_other_op is not None and usec_per_other_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_other_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_other_op = usec_per_other_op

    @property
    def time(self):
        """Gets the time of this ArrayHttpPerformance.  # noqa: E501

        Sample time in milliseconds since UNIX epoch  # noqa: E501

        :return: The time of this ArrayHttpPerformance.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this ArrayHttpPerformance.

        Sample time in milliseconds since UNIX epoch  # noqa: E501

        :param time: The time of this ArrayHttpPerformance.  # noqa: E501
        :type: int
        """

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ArrayHttpPerformance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArrayHttpPerformance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.4 Python SDK

    Pure Storage FlashBlade REST 1.4 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.4
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Linkaggregationgroup(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ports': 'list[Reference]',
        'add_ports': 'list[Reference]',
        'remove_ports': 'list[Reference]'
    }

    attribute_map = {
        'ports': 'ports',
        'add_ports': 'add_ports',
        'remove_ports': 'remove_ports'
    }

    def __init__(self, ports=None, add_ports=None, remove_ports=None):  # noqa: E501
        """Linkaggregationgroup - a model defined in Swagger"""  # noqa: E501

        self._ports = None
        self._add_ports = None
        self._remove_ports = None
        self.discriminator = None

        if ports is not None:
            self.ports = ports
        if add_ports is not None:
            self.add_ports = add_ports
        if remove_ports is not None:
            self.remove_ports = remove_ports

    @property
    def ports(self):
        """Gets the ports of this Linkaggregationgroup.  # noqa: E501


        :return: The ports of this Linkaggregationgroup.  # noqa: E501
        :rtype: list[Reference]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this Linkaggregationgroup.


        :param ports: The ports of this Linkaggregationgroup.  # noqa: E501
        :type: list[Reference]
        """

        self._ports = ports

    @property
    def add_ports(self):
        """Gets the add_ports of this Linkaggregationgroup.  # noqa: E501


        :return: The add_ports of this Linkaggregationgroup.  # noqa: E501
        :rtype: list[Reference]
        """
        return self._add_ports

    @add_ports.setter
    def add_ports(self, add_ports):
        """Sets the add_ports of this Linkaggregationgroup.


        :param add_ports: The add_ports of this Linkaggregationgroup.  # noqa: E501
        :type: list[Reference]
        """

        self._add_ports = add_ports

    @property
    def remove_ports(self):
        """Gets the remove_ports of this Linkaggregationgroup.  # noqa: E501


        :return: The remove_ports of this Linkaggregationgroup.  # noqa: E501
        :rtype: list[Reference]
        """
        return self._remove_ports

    @remove_ports.setter
    def remove_ports(self, remove_ports):
        """Sets the remove_ports of this Linkaggregationgroup.


        :param remove_ports: The remove_ports of this Linkaggregationgroup.  # noqa: E501
        :type: list[Reference]
        """

        self._remove_ports = remove_ports

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Linkaggregationgroup, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Linkaggregationgroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.8 Python SDK

    Pure Storage FlashBlade REST 1.8 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.8
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class NetworkInterface(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'address': 'str',
        'enabled': 'bool',
        'gateway': 'str',
        'mtu': 'int',
        'netmask': 'str',
        'services': 'list[str]',
        'type': 'str',
        'vlan': 'int'
    }

    attribute_map = {
        'name': 'name',
        'address': 'address',
        'enabled': 'enabled',
        'gateway': 'gateway',
        'mtu': 'mtu',
        'netmask': 'netmask',
        'services': 'services',
        'type': 'type',
        'vlan': 'vlan'
    }

    def __init__(self, name=None, address=None, enabled=None, gateway=None, mtu=None, netmask=None, services=None, type=None, vlan=None):  # noqa: E501
        """NetworkInterface - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._address = None
        self._enabled = None
        self._gateway = None
        self._mtu = None
        self._netmask = None
        self._services = None
        self._type = None
        self._vlan = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if address is not None:
            self.address = address
        if enabled is not None:
            self.enabled = enabled
        if gateway is not None:
            self.gateway = gateway
        if mtu is not None:
            self.mtu = mtu
        if netmask is not None:
            self.netmask = netmask
        if services is not None:
            self.services = services
        if type is not None:
            self.type = type
        if vlan is not None:
            self.vlan = vlan

    @property
    def name(self):
        """Gets the name of this NetworkInterface.  # noqa: E501

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :return: The name of this NetworkInterface.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NetworkInterface.

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :param name: The name of this NetworkInterface.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def address(self):
        """Gets the address of this NetworkInterface.  # noqa: E501


        :return: The address of this NetworkInterface.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this NetworkInterface.


        :param address: The address of this NetworkInterface.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def enabled(self):
        """Gets the enabled of this NetworkInterface.  # noqa: E501

        Indicates if subnet is enabled (true) or disabled (false). Enabled by default.  # noqa: E501

        :return: The enabled of this NetworkInterface.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this NetworkInterface.

        Indicates if subnet is enabled (true) or disabled (false). Enabled by default.  # noqa: E501

        :param enabled: The enabled of this NetworkInterface.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def gateway(self):
        """Gets the gateway of this NetworkInterface.  # noqa: E501


        :return: The gateway of this NetworkInterface.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this NetworkInterface.


        :param gateway: The gateway of this NetworkInterface.  # noqa: E501
        :type: str
        """

        self._gateway = gateway

    @property
    def mtu(self):
        """Gets the mtu of this NetworkInterface.  # noqa: E501

        Maximum message transfer unit (packet) size for the subnet in bytes. MTU setting cannot exceed the MTU of the corresponding physical interface. 1500 by default.  # noqa: E501

        :return: The mtu of this NetworkInterface.  # noqa: E501
        :rtype: int
        """
        return self._mtu

    @mtu.setter
    def mtu(self, mtu):
        """Sets the mtu of this NetworkInterface.

        Maximum message transfer unit (packet) size for the subnet in bytes. MTU setting cannot exceed the MTU of the corresponding physical interface. 1500 by default.  # noqa: E501

        :param mtu: The mtu of this NetworkInterface.  # noqa: E501
        :type: int
        """

        self._mtu = mtu

    @property
    def netmask(self):
        """Gets the netmask of this NetworkInterface.  # noqa: E501


        :return: The netmask of this NetworkInterface.  # noqa: E501
        :rtype: str
        """
        return self._netmask

    @netmask.setter
    def netmask(self, netmask):
        """Sets the netmask of this NetworkInterface.


        :param netmask: The netmask of this NetworkInterface.  # noqa: E501
        :type: str
        """

        self._netmask = netmask

    @property
    def services(self):
        """Gets the services of this NetworkInterface.  # noqa: E501


        :return: The services of this NetworkInterface.  # noqa: E501
        :rtype: list[str]
        """
        return self._services

    @services.setter
    def services(self, services):
        """Sets the services of this NetworkInterface.


        :param services: The services of this NetworkInterface.  # noqa: E501
        :type: list[str]
        """

        self._services = services

    @property
    def type(self):
        """Gets the type of this NetworkInterface.  # noqa: E501

        Possible values are vip.  # noqa: E501

        :return: The type of this NetworkInterface.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this NetworkInterface.

        Possible values are vip.  # noqa: E501

        :param type: The type of this NetworkInterface.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def vlan(self):
        """Gets the vlan of this NetworkInterface.  # noqa: E501


        :return: The vlan of this NetworkInterface.  # noqa: E501
        :rtype: int
        """
        return self._vlan

    @vlan.setter
    def vlan(self, vlan):
        """Sets the vlan of this NetworkInterface.


        :param vlan: The vlan of this NetworkInterface.  # noqa: E501
        :type: int
        """

        self._vlan = vlan

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NetworkInterface, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkInterface):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.10 Python SDK

    Pure Storage FlashBlade REST 1.10 Python SDK. Compatible with REST API versions 1.0 - 1.10. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.10
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Hardware(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'details': 'str',
        'identify_enabled': 'bool',
        'index': 'int',
        'model': 'str',
        'name': 'str',
        'serial': 'str',
        'slot': 'int',
        'speed': 'int',
        'status': 'str',
        'temperature': 'int',
        'type': 'str'
    }

    attribute_map = {
        'details': 'details',
        'identify_enabled': 'identify_enabled',
        'index': 'index',
        'model': 'model',
        'name': 'name',
        'serial': 'serial',
        'slot': 'slot',
        'speed': 'speed',
        'status': 'status',
        'temperature': 'temperature',
        'type': 'type'
    }

    def __init__(self, details=None, identify_enabled=None, index=None, model=None, name=None, serial=None, slot=None, speed=None, status=None, temperature=None, type=None):  # noqa: E501
        """Hardware - a model defined in Swagger"""  # noqa: E501

        self._details = None
        self._identify_enabled = None
        self._index = None
        self._model = None
        self._name = None
        self._serial = None
        self._slot = None
        self._speed = None
        self._status = None
        self._temperature = None
        self._type = None
        self.discriminator = None

        if details is not None:
            self.details = details
        if identify_enabled is not None:
            self.identify_enabled = identify_enabled
        if index is not None:
            self.index = index
        if model is not None:
            self.model = model
        if name is not None:
            self.name = name
        if serial is not None:
            self.serial = serial
        if slot is not None:
            self.slot = slot
        if speed is not None:
            self.speed = speed
        if status is not None:
            self.status = status
        if temperature is not None:
            self.temperature = temperature
        if type is not None:
            self.type = type

    @property
    def details(self):
        """Gets the details of this Hardware.  # noqa: E501

        detailed component status if not healthy  # noqa: E501

        :return: The details of this Hardware.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this Hardware.

        detailed component status if not healthy  # noqa: E501

        :param details: The details of this Hardware.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def identify_enabled(self):
        """Gets the identify_enabled of this Hardware.  # noqa: E501

        is visual identifier LED enabled? Modifiable  # noqa: E501

        :return: The identify_enabled of this Hardware.  # noqa: E501
        :rtype: bool
        """
        return self._identify_enabled

    @identify_enabled.setter
    def identify_enabled(self, identify_enabled):
        """Sets the identify_enabled of this Hardware.

        is visual identifier LED enabled? Modifiable  # noqa: E501

        :param identify_enabled: The identify_enabled of this Hardware.  # noqa: E501
        :type: bool
        """

        self._identify_enabled = identify_enabled

    @property
    def index(self):
        """Gets the index of this Hardware.  # noqa: E501

        position of the component within the array  # noqa: E501

        :return: The index of this Hardware.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this Hardware.

        position of the component within the array  # noqa: E501

        :param index: The index of this Hardware.  # noqa: E501
        :type: int
        """

        self._index = index

    @property
    def model(self):
        """Gets the model of this Hardware.  # noqa: E501

        model number of the component  # noqa: E501

        :return: The model of this Hardware.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this Hardware.

        model number of the component  # noqa: E501

        :param model: The model of this Hardware.  # noqa: E501
        :type: str
        """

        self._model = model

    @property
    def name(self):
        """Gets the name of this Hardware.  # noqa: E501

        component name  # noqa: E501

        :return: The name of this Hardware.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Hardware.

        component name  # noqa: E501

        :param name: The name of this Hardware.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def serial(self):
        """Gets the serial of this Hardware.  # noqa: E501

        serial number of the component  # noqa: E501

        :return: The serial of this Hardware.  # noqa: E501
        :rtype: str
        """
        return self._serial

    @serial.setter
    def serial(self, serial):
        """Sets the serial of this Hardware.

        serial number of the component  # noqa: E501

        :param serial: The serial of this Hardware.  # noqa: E501
        :type: str
        """

        self._serial = serial

    @property
    def slot(self):
        """Gets the slot of this Hardware.  # noqa: E501

        slot number of the PCI Express card that hosts the component  # noqa: E501

        :return: The slot of this Hardware.  # noqa: E501
        :rtype: int
        """
        return self._slot

    @slot.setter
    def slot(self, slot):
        """Sets the slot of this Hardware.

        slot number of the PCI Express card that hosts the component  # noqa: E501

        :param slot: The slot of this Hardware.  # noqa: E501
        :type: int
        """

        self._slot = slot

    @property
    def speed(self):
        """Gets the speed of this Hardware.  # noqa: E501

        speed (in b/s) at which the component is operating  # noqa: E501

        :return: The speed of this Hardware.  # noqa: E501
        :rtype: int
        """
        return self._speed

    @speed.setter
    def speed(self, speed):
        """Sets the speed of this Hardware.

        speed (in b/s) at which the component is operating  # noqa: E501

        :param speed: The speed of this Hardware.  # noqa: E501
        :type: int
        """

        self._speed = speed

    @property
    def status(self):
        """Gets the status of this Hardware.  # noqa: E501

        Component status. Possible values are critical, healthy, identifying, unhealthy, unknown, and unused.  # noqa: E501

        :return: The status of this Hardware.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Hardware.

        Component status. Possible values are critical, healthy, identifying, unhealthy, unknown, and unused.  # noqa: E501

        :param status: The status of this Hardware.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def temperature(self):
        """Gets the temperature of this Hardware.  # noqa: E501

        temperature reported by the component  # noqa: E501

        :return: The temperature of this Hardware.  # noqa: E501
        :rtype: int
        """
        return self._temperature

    @temperature.setter
    def temperature(self, temperature):
        """Sets the temperature of this Hardware.

        temperature reported by the component  # noqa: E501

        :param temperature: The temperature of this Hardware.  # noqa: E501
        :type: int
        """

        self._temperature = temperature

    @property
    def type(self):
        """Gets the type of this Hardware.  # noqa: E501

        Component type. Possible values are ch, eth, fan, fb, fm, pwr and xfm.  # noqa: E501

        :return: The type of this Hardware.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Hardware.

        Component type. Possible values are ch, eth, fan, fb, fm, pwr and xfm.  # noqa: E501

        :param type: The type of this Hardware.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Hardware, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Hardware):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.3 Python SDK

    Pure Storage FlashBlade REST 1.3 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.3
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Space(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'virtual': 'int',
        'data_reduction': 'float',
        'unique': 'int',
        'snapshots': 'int',
        'total_physical': 'int'
    }

    attribute_map = {
        'virtual': 'virtual',
        'data_reduction': 'data_reduction',
        'unique': 'unique',
        'snapshots': 'snapshots',
        'total_physical': 'total_physical'
    }

    def __init__(self, virtual=None, data_reduction=None, unique=None, snapshots=None, total_physical=None):  # noqa: E501
        """Space - a model defined in Swagger"""  # noqa: E501

        self._virtual = None
        self._data_reduction = None
        self._unique = None
        self._snapshots = None
        self._total_physical = None
        self.discriminator = None

        if virtual is not None:
            self.virtual = virtual
        if data_reduction is not None:
            self.data_reduction = data_reduction
        if unique is not None:
            self.unique = unique
        if snapshots is not None:
            self.snapshots = snapshots
        if total_physical is not None:
            self.total_physical = total_physical

    @property
    def virtual(self):
        """Gets the virtual of this Space.  # noqa: E501

        usage in bytes  # noqa: E501

        :return: The virtual of this Space.  # noqa: E501
        :rtype: int
        """
        return self._virtual

    @virtual.setter
    def virtual(self, virtual):
        """Sets the virtual of this Space.

        usage in bytes  # noqa: E501

        :param virtual: The virtual of this Space.  # noqa: E501
        :type: int
        """

        self._virtual = virtual

    @property
    def data_reduction(self):
        """Gets the data_reduction of this Space.  # noqa: E501

        reduction of data  # noqa: E501

        :return: The data_reduction of this Space.  # noqa: E501
        :rtype: float
        """
        return self._data_reduction

    @data_reduction.setter
    def data_reduction(self, data_reduction):
        """Sets the data_reduction of this Space.

        reduction of data  # noqa: E501

        :param data_reduction: The data_reduction of this Space.  # noqa: E501
        :type: float
        """

        self._data_reduction = data_reduction

    @property
    def unique(self):
        """Gets the unique of this Space.  # noqa: E501

        physical usage in bytes  # noqa: E501

        :return: The unique of this Space.  # noqa: E501
        :rtype: int
        """
        return self._unique

    @unique.setter
    def unique(self, unique):
        """Sets the unique of this Space.

        physical usage in bytes  # noqa: E501

        :param unique: The unique of this Space.  # noqa: E501
        :type: int
        """

        self._unique = unique

    @property
    def snapshots(self):
        """Gets the snapshots of this Space.  # noqa: E501

        physical usage by snapshots, other than unique in bytes  # noqa: E501

        :return: The snapshots of this Space.  # noqa: E501
        :rtype: int
        """
        return self._snapshots

    @snapshots.setter
    def snapshots(self, snapshots):
        """Sets the snapshots of this Space.

        physical usage by snapshots, other than unique in bytes  # noqa: E501

        :param snapshots: The snapshots of this Space.  # noqa: E501
        :type: int
        """

        self._snapshots = snapshots

    @property
    def total_physical(self):
        """Gets the total_physical of this Space.  # noqa: E501

        total physical usage (including snapshots) in bytes  # noqa: E501

        :return: The total_physical of this Space.  # noqa: E501
        :rtype: int
        """
        return self._total_physical

    @total_physical.setter
    def total_physical(self, total_physical):
        """Sets the total_physical of this Space.

        total physical usage (including snapshots) in bytes  # noqa: E501

        :param total_physical: The total_physical of this Space.  # noqa: E501
        :type: int
        """

        self._total_physical = total_physical

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Space, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Space):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.2 Python SDK

    Pure Storage FlashBlade REST 1.2 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.2
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PaginationInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'total_item_count': 'int',
        'continuation_token': 'str'
    }

    attribute_map = {
        'total_item_count': 'total_item_count',
        'continuation_token': 'continuation_token'
    }

    def __init__(self, total_item_count=None, continuation_token=None):  # noqa: E501
        """PaginationInfo - a model defined in Swagger"""  # noqa: E501

        self._total_item_count = None
        self._continuation_token = None
        self.discriminator = None

        if total_item_count is not None:
            self.total_item_count = total_item_count
        if continuation_token is not None:
            self.continuation_token = continuation_token

    @property
    def total_item_count(self):
        """Gets the total_item_count of this PaginationInfo.  # noqa: E501

        total number of items  # noqa: E501

        :return: The total_item_count of this PaginationInfo.  # noqa: E501
        :rtype: int
        """
        return self._total_item_count

    @total_item_count.setter
    def total_item_count(self, total_item_count):
        """Sets the total_item_count of this PaginationInfo.

        total number of items  # noqa: E501

        :param total_item_count: The total_item_count of this PaginationInfo.  # noqa: E501
        :type: int
        """

        self._total_item_count = total_item_count

    @property
    def continuation_token(self):
        """Gets the continuation_token of this PaginationInfo.  # noqa: E501

        continuation token  # noqa: E501

        :return: The continuation_token of this PaginationInfo.  # noqa: E501
        :rtype: str
        """
        return self._continuation_token

    @continuation_token.setter
    def continuation_token(self, continuation_token):
        """Sets the continuation_token of this PaginationInfo.

        continuation token  # noqa: E501

        :param continuation_token: The continuation_token of this PaginationInfo.  # noqa: E501
        :type: str
        """

        self._continuation_token = continuation_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaginationInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaginationInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# import apis into api package
from .admins_api import AdminsApi
from .admins_cache_api import AdminsCacheApi
from .alert_watchers_api import AlertWatchersApi
from .alerts_api import AlertsApi
from .array_connections_api import ArrayConnectionsApi
from .arrays_api import ArraysApi
from .audits_api import AuditsApi
from .authentication_api import AuthenticationApi
from .blade_api import BladeApi
from .bucket_replica_links_api import BucketReplicaLinksApi
from .buckets_api import BucketsApi
from .certificate_groups_api import CertificateGroupsApi
from .certificates_api import CertificatesApi
from .directory_services_api import DirectoryServicesApi
from .dns_api import DnsApi
from .file_system_replica_links_api import FileSystemReplicaLinksApi
from .file_system_snapshots_api import FileSystemSnapshotsApi
from .file_systems_api import FileSystemsApi
from .hardware_api import HardwareApi
from .hardware_connectors_api import HardwareConnectorsApi
from .keytabs_api import KeytabsApi
from .link_aggregation_groups_api import LinkAggregationGroupsApi
from .logs_api import LogsApi
from .network_interfaces_api import NetworkInterfacesApi
from .object_store_access_keys_api import ObjectStoreAccessKeysApi
from .object_store_accounts_api import ObjectStoreAccountsApi
from .object_store_remote_credentials_api import ObjectStoreRemoteCredentialsApi
from .object_store_users_api import ObjectStoreUsersApi
from .policies_api import PoliciesApi
from .quotas_groups_api import QuotasGroupsApi
from .quotas_settings_api import QuotasSettingsApi
from .quotas_users_api import QuotasUsersApi
from .smtp_api import SmtpApi
from .snmp_agents_api import SnmpAgentsApi
from .snmp_managers_api import SnmpManagersApi
from .subnets_api import SubnetsApi
from .support_api import SupportApi
from .targets_api import TargetsApi
from .usage_groups_api import UsageGroupsApi
from .usage_users_api import UsageUsersApi
from .version_api import VersionApi



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.10 Python SDK

    Pure Storage FlashBlade REST 1.10 Python SDK. Compatible with REST API versions 1.0 - 1.10. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.10
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FileSystemReplicaLink(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'direction': 'Direction',
        'id': 'str',
        'lag': 'int',
        'remote': 'FixedReferenceWithId',
        'status_details': 'str',
        'local_file_system': 'FixedReferenceWithId',
        'policies': 'list[LocationReference]',
        'recovery_point': 'int',
        'remote_file_system': 'FixedReferenceNoResourceType',
        'status': 'str'
    }

    attribute_map = {
        'direction': 'direction',
        'id': 'id',
        'lag': 'lag',
        'remote': 'remote',
        'status_details': 'status_details',
        'local_file_system': 'local_file_system',
        'policies': 'policies',
        'recovery_point': 'recovery_point',
        'remote_file_system': 'remote_file_system',
        'status': 'status'
    }

    def __init__(self, direction=None, id=None, lag=None, remote=None, status_details=None, local_file_system=None, policies=None, recovery_point=None, remote_file_system=None, status=None):  # noqa: E501
        """FileSystemReplicaLink - a model defined in Swagger"""  # noqa: E501

        self._direction = None
        self._id = None
        self._lag = None
        self._remote = None
        self._status_details = None
        self._local_file_system = None
        self._policies = None
        self._recovery_point = None
        self._remote_file_system = None
        self._status = None
        self.discriminator = None

        if direction is not None:
            self.direction = direction
        if id is not None:
            self.id = id
        if lag is not None:
            self.lag = lag
        if remote is not None:
            self.remote = remote
        if status_details is not None:
            self.status_details = status_details
        if local_file_system is not None:
            self.local_file_system = local_file_system
        if policies is not None:
            self.policies = policies
        if recovery_point is not None:
            self.recovery_point = recovery_point
        if remote_file_system is not None:
            self.remote_file_system = remote_file_system
        if status is not None:
            self.status = status

    @property
    def direction(self):
        """Gets the direction of this FileSystemReplicaLink.  # noqa: E501


        :return: The direction of this FileSystemReplicaLink.  # noqa: E501
        :rtype: Direction
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this FileSystemReplicaLink.


        :param direction: The direction of this FileSystemReplicaLink.  # noqa: E501
        :type: Direction
        """

        self._direction = direction

    @property
    def id(self):
        """Gets the id of this FileSystemReplicaLink.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this FileSystemReplicaLink.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FileSystemReplicaLink.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this FileSystemReplicaLink.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def lag(self):
        """Gets the lag of this FileSystemReplicaLink.  # noqa: E501

        Duration in milliseconds that represents how far behind the replication target is from the source. This is the time difference between current time and `recovery_point`.  # noqa: E501

        :return: The lag of this FileSystemReplicaLink.  # noqa: E501
        :rtype: int
        """
        return self._lag

    @lag.setter
    def lag(self, lag):
        """Sets the lag of this FileSystemReplicaLink.

        Duration in milliseconds that represents how far behind the replication target is from the source. This is the time difference between current time and `recovery_point`.  # noqa: E501

        :param lag: The lag of this FileSystemReplicaLink.  # noqa: E501
        :type: int
        """

        self._lag = lag

    @property
    def remote(self):
        """Gets the remote of this FileSystemReplicaLink.  # noqa: E501

        Reference to a remote target.  # noqa: E501

        :return: The remote of this FileSystemReplicaLink.  # noqa: E501
        :rtype: FixedReferenceWithId
        """
        return self._remote

    @remote.setter
    def remote(self, remote):
        """Sets the remote of this FileSystemReplicaLink.

        Reference to a remote target.  # noqa: E501

        :param remote: The remote of this FileSystemReplicaLink.  # noqa: E501
        :type: FixedReferenceWithId
        """

        self._remote = remote

    @property
    def status_details(self):
        """Gets the status_details of this FileSystemReplicaLink.  # noqa: E501

        Detailed information about the status of the replica link.  # noqa: E501

        :return: The status_details of this FileSystemReplicaLink.  # noqa: E501
        :rtype: str
        """
        return self._status_details

    @status_details.setter
    def status_details(self, status_details):
        """Sets the status_details of this FileSystemReplicaLink.

        Detailed information about the status of the replica link.  # noqa: E501

        :param status_details: The status_details of this FileSystemReplicaLink.  # noqa: E501
        :type: str
        """

        self._status_details = status_details

    @property
    def local_file_system(self):
        """Gets the local_file_system of this FileSystemReplicaLink.  # noqa: E501

        Reference to a local file system.  # noqa: E501

        :return: The local_file_system of this FileSystemReplicaLink.  # noqa: E501
        :rtype: FixedReferenceWithId
        """
        return self._local_file_system

    @local_file_system.setter
    def local_file_system(self, local_file_system):
        """Sets the local_file_system of this FileSystemReplicaLink.

        Reference to a local file system.  # noqa: E501

        :param local_file_system: The local_file_system of this FileSystemReplicaLink.  # noqa: E501
        :type: FixedReferenceWithId
        """

        self._local_file_system = local_file_system

    @property
    def policies(self):
        """Gets the policies of this FileSystemReplicaLink.  # noqa: E501


        :return: The policies of this FileSystemReplicaLink.  # noqa: E501
        :rtype: list[LocationReference]
        """
        return self._policies

    @policies.setter
    def policies(self, policies):
        """Sets the policies of this FileSystemReplicaLink.


        :param policies: The policies of this FileSystemReplicaLink.  # noqa: E501
        :type: list[LocationReference]
        """

        self._policies = policies

    @property
    def recovery_point(self):
        """Gets the recovery_point of this FileSystemReplicaLink.  # noqa: E501

        Time when the last replicated snapshot was created, in milliseconds since UNIX epoch. I.e. the recovery point if the file system is promoted.  # noqa: E501

        :return: The recovery_point of this FileSystemReplicaLink.  # noqa: E501
        :rtype: int
        """
        return self._recovery_point

    @recovery_point.setter
    def recovery_point(self, recovery_point):
        """Sets the recovery_point of this FileSystemReplicaLink.

        Time when the last replicated snapshot was created, in milliseconds since UNIX epoch. I.e. the recovery point if the file system is promoted.  # noqa: E501

        :param recovery_point: The recovery_point of this FileSystemReplicaLink.  # noqa: E501
        :type: int
        """

        self._recovery_point = recovery_point

    @property
    def remote_file_system(self):
        """Gets the remote_file_system of this FileSystemReplicaLink.  # noqa: E501

        Reference to a remote file system.  # noqa: E501

        :return: The remote_file_system of this FileSystemReplicaLink.  # noqa: E501
        :rtype: FixedReferenceNoResourceType
        """
        return self._remote_file_system

    @remote_file_system.setter
    def remote_file_system(self, remote_file_system):
        """Sets the remote_file_system of this FileSystemReplicaLink.

        Reference to a remote file system.  # noqa: E501

        :param remote_file_system: The remote_file_system of this FileSystemReplicaLink.  # noqa: E501
        :type: FixedReferenceNoResourceType
        """

        self._remote_file_system = remote_file_system

    @property
    def status(self):
        """Gets the status of this FileSystemReplicaLink.  # noqa: E501

        Status of the replica link. Values include replicating, idle, and unhealthy.  # noqa: E501

        :return: The status of this FileSystemReplicaLink.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this FileSystemReplicaLink.

        Status of the replica link. Values include replicating, idle, and unhealthy.  # noqa: E501

        :param status: The status of this FileSystemReplicaLink.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FileSystemReplicaLink, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileSystemReplicaLink):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.11 Python SDK

    Pure Storage FlashBlade REST 1.11 Python SDK. Compatible with REST API versions 1.0 - 1.11. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.11
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ArrayNfsPerformance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'accesses_per_sec': 'int',
        'aggregate_file_metadata_creates_per_sec': 'int',
        'aggregate_file_metadata_modifies_per_sec': 'int',
        'aggregate_file_metadata_reads_per_sec': 'int',
        'aggregate_share_metadata_reads_per_sec': 'int',
        'aggregate_usec_per_file_metadata_create_op': 'int',
        'aggregate_usec_per_file_metadata_modify_op': 'int',
        'aggregate_usec_per_file_metadata_read_op': 'int',
        'aggregate_usec_per_share_metadata_read_op': 'int',
        'creates_per_sec': 'int',
        'fsinfos_per_sec': 'int',
        'fsstats_per_sec': 'int',
        'getattrs_per_sec': 'int',
        'links_per_sec': 'int',
        'lookups_per_sec': 'int',
        'mkdirs_per_sec': 'int',
        'others_per_sec': 'int',
        'pathconfs_per_sec': 'int',
        'reads_per_sec': 'int',
        'readdirs_per_sec': 'int',
        'readdirpluses_per_sec': 'int',
        'readlinks_per_sec': 'int',
        'removes_per_sec': 'int',
        'renames_per_sec': 'int',
        'rmdirs_per_sec': 'int',
        'setattrs_per_sec': 'int',
        'symlinks_per_sec': 'int',
        'time': 'int',
        'writes_per_sec': 'int',
        'usec_per_access_op': 'int',
        'usec_per_create_op': 'int',
        'usec_per_fsinfo_op': 'int',
        'usec_per_fsstat_op': 'int',
        'usec_per_getattr_op': 'int',
        'usec_per_link_op': 'int',
        'usec_per_lookup_op': 'int',
        'usec_per_mkdir_op': 'int',
        'usec_per_other_op': 'int',
        'usec_per_pathconf_op': 'int',
        'usec_per_read_op': 'int',
        'usec_per_readdir_op': 'int',
        'usec_per_readdirplus_op': 'int',
        'usec_per_readlink_op': 'int',
        'usec_per_remove_op': 'int',
        'usec_per_rename_op': 'int',
        'usec_per_rmdir_op': 'int',
        'usec_per_setattr_op': 'int',
        'usec_per_symlink_op': 'int',
        'usec_per_write_op': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'accesses_per_sec': 'accesses_per_sec',
        'aggregate_file_metadata_creates_per_sec': 'aggregate_file_metadata_creates_per_sec',
        'aggregate_file_metadata_modifies_per_sec': 'aggregate_file_metadata_modifies_per_sec',
        'aggregate_file_metadata_reads_per_sec': 'aggregate_file_metadata_reads_per_sec',
        'aggregate_share_metadata_reads_per_sec': 'aggregate_share_metadata_reads_per_sec',
        'aggregate_usec_per_file_metadata_create_op': 'aggregate_usec_per_file_metadata_create_op',
        'aggregate_usec_per_file_metadata_modify_op': 'aggregate_usec_per_file_metadata_modify_op',
        'aggregate_usec_per_file_metadata_read_op': 'aggregate_usec_per_file_metadata_read_op',
        'aggregate_usec_per_share_metadata_read_op': 'aggregate_usec_per_share_metadata_read_op',
        'creates_per_sec': 'creates_per_sec',
        'fsinfos_per_sec': 'fsinfos_per_sec',
        'fsstats_per_sec': 'fsstats_per_sec',
        'getattrs_per_sec': 'getattrs_per_sec',
        'links_per_sec': 'links_per_sec',
        'lookups_per_sec': 'lookups_per_sec',
        'mkdirs_per_sec': 'mkdirs_per_sec',
        'others_per_sec': 'others_per_sec',
        'pathconfs_per_sec': 'pathconfs_per_sec',
        'reads_per_sec': 'reads_per_sec',
        'readdirs_per_sec': 'readdirs_per_sec',
        'readdirpluses_per_sec': 'readdirpluses_per_sec',
        'readlinks_per_sec': 'readlinks_per_sec',
        'removes_per_sec': 'removes_per_sec',
        'renames_per_sec': 'renames_per_sec',
        'rmdirs_per_sec': 'rmdirs_per_sec',
        'setattrs_per_sec': 'setattrs_per_sec',
        'symlinks_per_sec': 'symlinks_per_sec',
        'time': 'time',
        'writes_per_sec': 'writes_per_sec',
        'usec_per_access_op': 'usec_per_access_op',
        'usec_per_create_op': 'usec_per_create_op',
        'usec_per_fsinfo_op': 'usec_per_fsinfo_op',
        'usec_per_fsstat_op': 'usec_per_fsstat_op',
        'usec_per_getattr_op': 'usec_per_getattr_op',
        'usec_per_link_op': 'usec_per_link_op',
        'usec_per_lookup_op': 'usec_per_lookup_op',
        'usec_per_mkdir_op': 'usec_per_mkdir_op',
        'usec_per_other_op': 'usec_per_other_op',
        'usec_per_pathconf_op': 'usec_per_pathconf_op',
        'usec_per_read_op': 'usec_per_read_op',
        'usec_per_readdir_op': 'usec_per_readdir_op',
        'usec_per_readdirplus_op': 'usec_per_readdirplus_op',
        'usec_per_readlink_op': 'usec_per_readlink_op',
        'usec_per_remove_op': 'usec_per_remove_op',
        'usec_per_rename_op': 'usec_per_rename_op',
        'usec_per_rmdir_op': 'usec_per_rmdir_op',
        'usec_per_setattr_op': 'usec_per_setattr_op',
        'usec_per_symlink_op': 'usec_per_symlink_op',
        'usec_per_write_op': 'usec_per_write_op'
    }

    def __init__(self, id=None, name=None, accesses_per_sec=None, aggregate_file_metadata_creates_per_sec=None, aggregate_file_metadata_modifies_per_sec=None, aggregate_file_metadata_reads_per_sec=None, aggregate_share_metadata_reads_per_sec=None, aggregate_usec_per_file_metadata_create_op=None, aggregate_usec_per_file_metadata_modify_op=None, aggregate_usec_per_file_metadata_read_op=None, aggregate_usec_per_share_metadata_read_op=None, creates_per_sec=None, fsinfos_per_sec=None, fsstats_per_sec=None, getattrs_per_sec=None, links_per_sec=None, lookups_per_sec=None, mkdirs_per_sec=None, others_per_sec=None, pathconfs_per_sec=None, reads_per_sec=None, readdirs_per_sec=None, readdirpluses_per_sec=None, readlinks_per_sec=None, removes_per_sec=None, renames_per_sec=None, rmdirs_per_sec=None, setattrs_per_sec=None, symlinks_per_sec=None, time=None, writes_per_sec=None, usec_per_access_op=None, usec_per_create_op=None, usec_per_fsinfo_op=None, usec_per_fsstat_op=None, usec_per_getattr_op=None, usec_per_link_op=None, usec_per_lookup_op=None, usec_per_mkdir_op=None, usec_per_other_op=None, usec_per_pathconf_op=None, usec_per_read_op=None, usec_per_readdir_op=None, usec_per_readdirplus_op=None, usec_per_readlink_op=None, usec_per_remove_op=None, usec_per_rename_op=None, usec_per_rmdir_op=None, usec_per_setattr_op=None, usec_per_symlink_op=None, usec_per_write_op=None):  # noqa: E501
        """ArrayNfsPerformance - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._accesses_per_sec = None
        self._aggregate_file_metadata_creates_per_sec = None
        self._aggregate_file_metadata_modifies_per_sec = None
        self._aggregate_file_metadata_reads_per_sec = None
        self._aggregate_share_metadata_reads_per_sec = None
        self._aggregate_usec_per_file_metadata_create_op = None
        self._aggregate_usec_per_file_metadata_modify_op = None
        self._aggregate_usec_per_file_metadata_read_op = None
        self._aggregate_usec_per_share_metadata_read_op = None
        self._creates_per_sec = None
        self._fsinfos_per_sec = None
        self._fsstats_per_sec = None
        self._getattrs_per_sec = None
        self._links_per_sec = None
        self._lookups_per_sec = None
        self._mkdirs_per_sec = None
        self._others_per_sec = None
        self._pathconfs_per_sec = None
        self._reads_per_sec = None
        self._readdirs_per_sec = None
        self._readdirpluses_per_sec = None
        self._readlinks_per_sec = None
        self._removes_per_sec = None
        self._renames_per_sec = None
        self._rmdirs_per_sec = None
        self._setattrs_per_sec = None
        self._symlinks_per_sec = None
        self._time = None
        self._writes_per_sec = None
        self._usec_per_access_op = None
        self._usec_per_create_op = None
        self._usec_per_fsinfo_op = None
        self._usec_per_fsstat_op = None
        self._usec_per_getattr_op = None
        self._usec_per_link_op = None
        self._usec_per_lookup_op = None
        self._usec_per_mkdir_op = None
        self._usec_per_other_op = None
        self._usec_per_pathconf_op = None
        self._usec_per_read_op = None
        self._usec_per_readdir_op = None
        self._usec_per_readdirplus_op = None
        self._usec_per_readlink_op = None
        self._usec_per_remove_op = None
        self._usec_per_rename_op = None
        self._usec_per_rmdir_op = None
        self._usec_per_setattr_op = None
        self._usec_per_symlink_op = None
        self._usec_per_write_op = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if accesses_per_sec is not None:
            self.accesses_per_sec = accesses_per_sec
        if aggregate_file_metadata_creates_per_sec is not None:
            self.aggregate_file_metadata_creates_per_sec = aggregate_file_metadata_creates_per_sec
        if aggregate_file_metadata_modifies_per_sec is not None:
            self.aggregate_file_metadata_modifies_per_sec = aggregate_file_metadata_modifies_per_sec
        if aggregate_file_metadata_reads_per_sec is not None:
            self.aggregate_file_metadata_reads_per_sec = aggregate_file_metadata_reads_per_sec
        if aggregate_share_metadata_reads_per_sec is not None:
            self.aggregate_share_metadata_reads_per_sec = aggregate_share_metadata_reads_per_sec
        if aggregate_usec_per_file_metadata_create_op is not None:
            self.aggregate_usec_per_file_metadata_create_op = aggregate_usec_per_file_metadata_create_op
        if aggregate_usec_per_file_metadata_modify_op is not None:
            self.aggregate_usec_per_file_metadata_modify_op = aggregate_usec_per_file_metadata_modify_op
        if aggregate_usec_per_file_metadata_read_op is not None:
            self.aggregate_usec_per_file_metadata_read_op = aggregate_usec_per_file_metadata_read_op
        if aggregate_usec_per_share_metadata_read_op is not None:
            self.aggregate_usec_per_share_metadata_read_op = aggregate_usec_per_share_metadata_read_op
        if creates_per_sec is not None:
            self.creates_per_sec = creates_per_sec
        if fsinfos_per_sec is not None:
            self.fsinfos_per_sec = fsinfos_per_sec
        if fsstats_per_sec is not None:
            self.fsstats_per_sec = fsstats_per_sec
        if getattrs_per_sec is not None:
            self.getattrs_per_sec = getattrs_per_sec
        if links_per_sec is not None:
            self.links_per_sec = links_per_sec
        if lookups_per_sec is not None:
            self.lookups_per_sec = lookups_per_sec
        if mkdirs_per_sec is not None:
            self.mkdirs_per_sec = mkdirs_per_sec
        if others_per_sec is not None:
            self.others_per_sec = others_per_sec
        if pathconfs_per_sec is not None:
            self.pathconfs_per_sec = pathconfs_per_sec
        if reads_per_sec is not None:
            self.reads_per_sec = reads_per_sec
        if readdirs_per_sec is not None:
            self.readdirs_per_sec = readdirs_per_sec
        if readdirpluses_per_sec is not None:
            self.readdirpluses_per_sec = readdirpluses_per_sec
        if readlinks_per_sec is not None:
            self.readlinks_per_sec = readlinks_per_sec
        if removes_per_sec is not None:
            self.removes_per_sec = removes_per_sec
        if renames_per_sec is not None:
            self.renames_per_sec = renames_per_sec
        if rmdirs_per_sec is not None:
            self.rmdirs_per_sec = rmdirs_per_sec
        if setattrs_per_sec is not None:
            self.setattrs_per_sec = setattrs_per_sec
        if symlinks_per_sec is not None:
            self.symlinks_per_sec = symlinks_per_sec
        if time is not None:
            self.time = time
        if writes_per_sec is not None:
            self.writes_per_sec = writes_per_sec
        if usec_per_access_op is not None:
            self.usec_per_access_op = usec_per_access_op
        if usec_per_create_op is not None:
            self.usec_per_create_op = usec_per_create_op
        if usec_per_fsinfo_op is not None:
            self.usec_per_fsinfo_op = usec_per_fsinfo_op
        if usec_per_fsstat_op is not None:
            self.usec_per_fsstat_op = usec_per_fsstat_op
        if usec_per_getattr_op is not None:
            self.usec_per_getattr_op = usec_per_getattr_op
        if usec_per_link_op is not None:
            self.usec_per_link_op = usec_per_link_op
        if usec_per_lookup_op is not None:
            self.usec_per_lookup_op = usec_per_lookup_op
        if usec_per_mkdir_op is not None:
            self.usec_per_mkdir_op = usec_per_mkdir_op
        if usec_per_other_op is not None:
            self.usec_per_other_op = usec_per_other_op
        if usec_per_pathconf_op is not None:
            self.usec_per_pathconf_op = usec_per_pathconf_op
        if usec_per_read_op is not None:
            self.usec_per_read_op = usec_per_read_op
        if usec_per_readdir_op is not None:
            self.usec_per_readdir_op = usec_per_readdir_op
        if usec_per_readdirplus_op is not None:
            self.usec_per_readdirplus_op = usec_per_readdirplus_op
        if usec_per_readlink_op is not None:
            self.usec_per_readlink_op = usec_per_readlink_op
        if usec_per_remove_op is not None:
            self.usec_per_remove_op = usec_per_remove_op
        if usec_per_rename_op is not None:
            self.usec_per_rename_op = usec_per_rename_op
        if usec_per_rmdir_op is not None:
            self.usec_per_rmdir_op = usec_per_rmdir_op
        if usec_per_setattr_op is not None:
            self.usec_per_setattr_op = usec_per_setattr_op
        if usec_per_symlink_op is not None:
            self.usec_per_symlink_op = usec_per_symlink_op
        if usec_per_write_op is not None:
            self.usec_per_write_op = usec_per_write_op

    @property
    def id(self):
        """Gets the id of this ArrayNfsPerformance.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this ArrayNfsPerformance.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ArrayNfsPerformance.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this ArrayNfsPerformance.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ArrayNfsPerformance.  # noqa: E501

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :return: The name of this ArrayNfsPerformance.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ArrayNfsPerformance.

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :param name: The name of this ArrayNfsPerformance.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def accesses_per_sec(self):
        """Gets the accesses_per_sec of this ArrayNfsPerformance.  # noqa: E501

        ACCESS requests processed per second.  # noqa: E501

        :return: The accesses_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._accesses_per_sec

    @accesses_per_sec.setter
    def accesses_per_sec(self, accesses_per_sec):
        """Sets the accesses_per_sec of this ArrayNfsPerformance.

        ACCESS requests processed per second.  # noqa: E501

        :param accesses_per_sec: The accesses_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if accesses_per_sec is not None and accesses_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `accesses_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._accesses_per_sec = accesses_per_sec

    @property
    def aggregate_file_metadata_creates_per_sec(self):
        """Gets the aggregate_file_metadata_creates_per_sec of this ArrayNfsPerformance.  # noqa: E501

        Sum of file-level or directory-level create-like metadata requests per second. Includes CREATE, LINK, MKDIR, and SYMLINK.  # noqa: E501

        :return: The aggregate_file_metadata_creates_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._aggregate_file_metadata_creates_per_sec

    @aggregate_file_metadata_creates_per_sec.setter
    def aggregate_file_metadata_creates_per_sec(self, aggregate_file_metadata_creates_per_sec):
        """Sets the aggregate_file_metadata_creates_per_sec of this ArrayNfsPerformance.

        Sum of file-level or directory-level create-like metadata requests per second. Includes CREATE, LINK, MKDIR, and SYMLINK.  # noqa: E501

        :param aggregate_file_metadata_creates_per_sec: The aggregate_file_metadata_creates_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if aggregate_file_metadata_creates_per_sec is not None and aggregate_file_metadata_creates_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `aggregate_file_metadata_creates_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._aggregate_file_metadata_creates_per_sec = aggregate_file_metadata_creates_per_sec

    @property
    def aggregate_file_metadata_modifies_per_sec(self):
        """Gets the aggregate_file_metadata_modifies_per_sec of this ArrayNfsPerformance.  # noqa: E501

        Sum of file-level or directory-level modify-like and delete-like metadata requests per second. Includes REMOVE, RENAME, RMDIR, and SETATTR.  # noqa: E501

        :return: The aggregate_file_metadata_modifies_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._aggregate_file_metadata_modifies_per_sec

    @aggregate_file_metadata_modifies_per_sec.setter
    def aggregate_file_metadata_modifies_per_sec(self, aggregate_file_metadata_modifies_per_sec):
        """Sets the aggregate_file_metadata_modifies_per_sec of this ArrayNfsPerformance.

        Sum of file-level or directory-level modify-like and delete-like metadata requests per second. Includes REMOVE, RENAME, RMDIR, and SETATTR.  # noqa: E501

        :param aggregate_file_metadata_modifies_per_sec: The aggregate_file_metadata_modifies_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if aggregate_file_metadata_modifies_per_sec is not None and aggregate_file_metadata_modifies_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `aggregate_file_metadata_modifies_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._aggregate_file_metadata_modifies_per_sec = aggregate_file_metadata_modifies_per_sec

    @property
    def aggregate_file_metadata_reads_per_sec(self):
        """Gets the aggregate_file_metadata_reads_per_sec of this ArrayNfsPerformance.  # noqa: E501

        Sum of file-level or directory-level read-like metadata requests per second. Includes GETATTR, LOOKUP, PATHCONF, READDIR, READDIRPLUS, and READLINK.  # noqa: E501

        :return: The aggregate_file_metadata_reads_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._aggregate_file_metadata_reads_per_sec

    @aggregate_file_metadata_reads_per_sec.setter
    def aggregate_file_metadata_reads_per_sec(self, aggregate_file_metadata_reads_per_sec):
        """Sets the aggregate_file_metadata_reads_per_sec of this ArrayNfsPerformance.

        Sum of file-level or directory-level read-like metadata requests per second. Includes GETATTR, LOOKUP, PATHCONF, READDIR, READDIRPLUS, and READLINK.  # noqa: E501

        :param aggregate_file_metadata_reads_per_sec: The aggregate_file_metadata_reads_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if aggregate_file_metadata_reads_per_sec is not None and aggregate_file_metadata_reads_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `aggregate_file_metadata_reads_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._aggregate_file_metadata_reads_per_sec = aggregate_file_metadata_reads_per_sec

    @property
    def aggregate_share_metadata_reads_per_sec(self):
        """Gets the aggregate_share_metadata_reads_per_sec of this ArrayNfsPerformance.  # noqa: E501

        Sum of share-level read-like metadata requests per second. Includes ACCESS, FSINFO, and FSSTAT.  # noqa: E501

        :return: The aggregate_share_metadata_reads_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._aggregate_share_metadata_reads_per_sec

    @aggregate_share_metadata_reads_per_sec.setter
    def aggregate_share_metadata_reads_per_sec(self, aggregate_share_metadata_reads_per_sec):
        """Sets the aggregate_share_metadata_reads_per_sec of this ArrayNfsPerformance.

        Sum of share-level read-like metadata requests per second. Includes ACCESS, FSINFO, and FSSTAT.  # noqa: E501

        :param aggregate_share_metadata_reads_per_sec: The aggregate_share_metadata_reads_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if aggregate_share_metadata_reads_per_sec is not None and aggregate_share_metadata_reads_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `aggregate_share_metadata_reads_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._aggregate_share_metadata_reads_per_sec = aggregate_share_metadata_reads_per_sec

    @property
    def aggregate_usec_per_file_metadata_create_op(self):
        """Gets the aggregate_usec_per_file_metadata_create_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a file-level or directory-level create-like metadata request. Includes CREATE, LINK, MKDIR, and SYMLINK.  # noqa: E501

        :return: The aggregate_usec_per_file_metadata_create_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._aggregate_usec_per_file_metadata_create_op

    @aggregate_usec_per_file_metadata_create_op.setter
    def aggregate_usec_per_file_metadata_create_op(self, aggregate_usec_per_file_metadata_create_op):
        """Sets the aggregate_usec_per_file_metadata_create_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a file-level or directory-level create-like metadata request. Includes CREATE, LINK, MKDIR, and SYMLINK.  # noqa: E501

        :param aggregate_usec_per_file_metadata_create_op: The aggregate_usec_per_file_metadata_create_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if aggregate_usec_per_file_metadata_create_op is not None and aggregate_usec_per_file_metadata_create_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `aggregate_usec_per_file_metadata_create_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._aggregate_usec_per_file_metadata_create_op = aggregate_usec_per_file_metadata_create_op

    @property
    def aggregate_usec_per_file_metadata_modify_op(self):
        """Gets the aggregate_usec_per_file_metadata_modify_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a file-level or directory-level modify-like or delete-like metadata request. Includes REMOVE, RENAME, RMDIR, and SETATTR.  # noqa: E501

        :return: The aggregate_usec_per_file_metadata_modify_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._aggregate_usec_per_file_metadata_modify_op

    @aggregate_usec_per_file_metadata_modify_op.setter
    def aggregate_usec_per_file_metadata_modify_op(self, aggregate_usec_per_file_metadata_modify_op):
        """Sets the aggregate_usec_per_file_metadata_modify_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a file-level or directory-level modify-like or delete-like metadata request. Includes REMOVE, RENAME, RMDIR, and SETATTR.  # noqa: E501

        :param aggregate_usec_per_file_metadata_modify_op: The aggregate_usec_per_file_metadata_modify_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if aggregate_usec_per_file_metadata_modify_op is not None and aggregate_usec_per_file_metadata_modify_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `aggregate_usec_per_file_metadata_modify_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._aggregate_usec_per_file_metadata_modify_op = aggregate_usec_per_file_metadata_modify_op

    @property
    def aggregate_usec_per_file_metadata_read_op(self):
        """Gets the aggregate_usec_per_file_metadata_read_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a file-level or directory-level read-like metadata request. Includes GETATTR, LOOKUP, PATHCONF, READDIR, READDIRPLUS, and READLINK.  # noqa: E501

        :return: The aggregate_usec_per_file_metadata_read_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._aggregate_usec_per_file_metadata_read_op

    @aggregate_usec_per_file_metadata_read_op.setter
    def aggregate_usec_per_file_metadata_read_op(self, aggregate_usec_per_file_metadata_read_op):
        """Sets the aggregate_usec_per_file_metadata_read_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a file-level or directory-level read-like metadata request. Includes GETATTR, LOOKUP, PATHCONF, READDIR, READDIRPLUS, and READLINK.  # noqa: E501

        :param aggregate_usec_per_file_metadata_read_op: The aggregate_usec_per_file_metadata_read_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if aggregate_usec_per_file_metadata_read_op is not None and aggregate_usec_per_file_metadata_read_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `aggregate_usec_per_file_metadata_read_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._aggregate_usec_per_file_metadata_read_op = aggregate_usec_per_file_metadata_read_op

    @property
    def aggregate_usec_per_share_metadata_read_op(self):
        """Gets the aggregate_usec_per_share_metadata_read_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a share-level read-like metadata request. Includes ACCESS, FSINFO, and FSSTAT.  # noqa: E501

        :return: The aggregate_usec_per_share_metadata_read_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._aggregate_usec_per_share_metadata_read_op

    @aggregate_usec_per_share_metadata_read_op.setter
    def aggregate_usec_per_share_metadata_read_op(self, aggregate_usec_per_share_metadata_read_op):
        """Sets the aggregate_usec_per_share_metadata_read_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a share-level read-like metadata request. Includes ACCESS, FSINFO, and FSSTAT.  # noqa: E501

        :param aggregate_usec_per_share_metadata_read_op: The aggregate_usec_per_share_metadata_read_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if aggregate_usec_per_share_metadata_read_op is not None and aggregate_usec_per_share_metadata_read_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `aggregate_usec_per_share_metadata_read_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._aggregate_usec_per_share_metadata_read_op = aggregate_usec_per_share_metadata_read_op

    @property
    def creates_per_sec(self):
        """Gets the creates_per_sec of this ArrayNfsPerformance.  # noqa: E501

        CREATE requests processed per second.  # noqa: E501

        :return: The creates_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._creates_per_sec

    @creates_per_sec.setter
    def creates_per_sec(self, creates_per_sec):
        """Sets the creates_per_sec of this ArrayNfsPerformance.

        CREATE requests processed per second.  # noqa: E501

        :param creates_per_sec: The creates_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if creates_per_sec is not None and creates_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `creates_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._creates_per_sec = creates_per_sec

    @property
    def fsinfos_per_sec(self):
        """Gets the fsinfos_per_sec of this ArrayNfsPerformance.  # noqa: E501

        FSINFO requests processed per second.  # noqa: E501

        :return: The fsinfos_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._fsinfos_per_sec

    @fsinfos_per_sec.setter
    def fsinfos_per_sec(self, fsinfos_per_sec):
        """Sets the fsinfos_per_sec of this ArrayNfsPerformance.

        FSINFO requests processed per second.  # noqa: E501

        :param fsinfos_per_sec: The fsinfos_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if fsinfos_per_sec is not None and fsinfos_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `fsinfos_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._fsinfos_per_sec = fsinfos_per_sec

    @property
    def fsstats_per_sec(self):
        """Gets the fsstats_per_sec of this ArrayNfsPerformance.  # noqa: E501

        FSSTAT requests processed per second.  # noqa: E501

        :return: The fsstats_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._fsstats_per_sec

    @fsstats_per_sec.setter
    def fsstats_per_sec(self, fsstats_per_sec):
        """Sets the fsstats_per_sec of this ArrayNfsPerformance.

        FSSTAT requests processed per second.  # noqa: E501

        :param fsstats_per_sec: The fsstats_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if fsstats_per_sec is not None and fsstats_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `fsstats_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._fsstats_per_sec = fsstats_per_sec

    @property
    def getattrs_per_sec(self):
        """Gets the getattrs_per_sec of this ArrayNfsPerformance.  # noqa: E501

        GETATTR requests processed per second.  # noqa: E501

        :return: The getattrs_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._getattrs_per_sec

    @getattrs_per_sec.setter
    def getattrs_per_sec(self, getattrs_per_sec):
        """Sets the getattrs_per_sec of this ArrayNfsPerformance.

        GETATTR requests processed per second.  # noqa: E501

        :param getattrs_per_sec: The getattrs_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if getattrs_per_sec is not None and getattrs_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `getattrs_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._getattrs_per_sec = getattrs_per_sec

    @property
    def links_per_sec(self):
        """Gets the links_per_sec of this ArrayNfsPerformance.  # noqa: E501

        LINK requests processed per second.  # noqa: E501

        :return: The links_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._links_per_sec

    @links_per_sec.setter
    def links_per_sec(self, links_per_sec):
        """Sets the links_per_sec of this ArrayNfsPerformance.

        LINK requests processed per second.  # noqa: E501

        :param links_per_sec: The links_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if links_per_sec is not None and links_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `links_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._links_per_sec = links_per_sec

    @property
    def lookups_per_sec(self):
        """Gets the lookups_per_sec of this ArrayNfsPerformance.  # noqa: E501

        LOOKUP requests processed per second.  # noqa: E501

        :return: The lookups_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._lookups_per_sec

    @lookups_per_sec.setter
    def lookups_per_sec(self, lookups_per_sec):
        """Sets the lookups_per_sec of this ArrayNfsPerformance.

        LOOKUP requests processed per second.  # noqa: E501

        :param lookups_per_sec: The lookups_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if lookups_per_sec is not None and lookups_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `lookups_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._lookups_per_sec = lookups_per_sec

    @property
    def mkdirs_per_sec(self):
        """Gets the mkdirs_per_sec of this ArrayNfsPerformance.  # noqa: E501

        MKDIR requests processed per second.  # noqa: E501

        :return: The mkdirs_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._mkdirs_per_sec

    @mkdirs_per_sec.setter
    def mkdirs_per_sec(self, mkdirs_per_sec):
        """Sets the mkdirs_per_sec of this ArrayNfsPerformance.

        MKDIR requests processed per second.  # noqa: E501

        :param mkdirs_per_sec: The mkdirs_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if mkdirs_per_sec is not None and mkdirs_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `mkdirs_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._mkdirs_per_sec = mkdirs_per_sec

    @property
    def others_per_sec(self):
        """Gets the others_per_sec of this ArrayNfsPerformance.  # noqa: E501

        All other requests processed per second.  # noqa: E501

        :return: The others_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._others_per_sec

    @others_per_sec.setter
    def others_per_sec(self, others_per_sec):
        """Sets the others_per_sec of this ArrayNfsPerformance.

        All other requests processed per second.  # noqa: E501

        :param others_per_sec: The others_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if others_per_sec is not None and others_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `others_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._others_per_sec = others_per_sec

    @property
    def pathconfs_per_sec(self):
        """Gets the pathconfs_per_sec of this ArrayNfsPerformance.  # noqa: E501

        PATHCONF requests processed per second.  # noqa: E501

        :return: The pathconfs_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._pathconfs_per_sec

    @pathconfs_per_sec.setter
    def pathconfs_per_sec(self, pathconfs_per_sec):
        """Sets the pathconfs_per_sec of this ArrayNfsPerformance.

        PATHCONF requests processed per second.  # noqa: E501

        :param pathconfs_per_sec: The pathconfs_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if pathconfs_per_sec is not None and pathconfs_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `pathconfs_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._pathconfs_per_sec = pathconfs_per_sec

    @property
    def reads_per_sec(self):
        """Gets the reads_per_sec of this ArrayNfsPerformance.  # noqa: E501

        READ requests processed per second.  # noqa: E501

        :return: The reads_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._reads_per_sec

    @reads_per_sec.setter
    def reads_per_sec(self, reads_per_sec):
        """Sets the reads_per_sec of this ArrayNfsPerformance.

        READ requests processed per second.  # noqa: E501

        :param reads_per_sec: The reads_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if reads_per_sec is not None and reads_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `reads_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._reads_per_sec = reads_per_sec

    @property
    def readdirs_per_sec(self):
        """Gets the readdirs_per_sec of this ArrayNfsPerformance.  # noqa: E501

        READDIR requests processed per second.  # noqa: E501

        :return: The readdirs_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._readdirs_per_sec

    @readdirs_per_sec.setter
    def readdirs_per_sec(self, readdirs_per_sec):
        """Sets the readdirs_per_sec of this ArrayNfsPerformance.

        READDIR requests processed per second.  # noqa: E501

        :param readdirs_per_sec: The readdirs_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if readdirs_per_sec is not None and readdirs_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `readdirs_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._readdirs_per_sec = readdirs_per_sec

    @property
    def readdirpluses_per_sec(self):
        """Gets the readdirpluses_per_sec of this ArrayNfsPerformance.  # noqa: E501

        READDIRPLUS requests processed per second.  # noqa: E501

        :return: The readdirpluses_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._readdirpluses_per_sec

    @readdirpluses_per_sec.setter
    def readdirpluses_per_sec(self, readdirpluses_per_sec):
        """Sets the readdirpluses_per_sec of this ArrayNfsPerformance.

        READDIRPLUS requests processed per second.  # noqa: E501

        :param readdirpluses_per_sec: The readdirpluses_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if readdirpluses_per_sec is not None and readdirpluses_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `readdirpluses_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._readdirpluses_per_sec = readdirpluses_per_sec

    @property
    def readlinks_per_sec(self):
        """Gets the readlinks_per_sec of this ArrayNfsPerformance.  # noqa: E501

        READLINK requests processed per second.  # noqa: E501

        :return: The readlinks_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._readlinks_per_sec

    @readlinks_per_sec.setter
    def readlinks_per_sec(self, readlinks_per_sec):
        """Sets the readlinks_per_sec of this ArrayNfsPerformance.

        READLINK requests processed per second.  # noqa: E501

        :param readlinks_per_sec: The readlinks_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if readlinks_per_sec is not None and readlinks_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `readlinks_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._readlinks_per_sec = readlinks_per_sec

    @property
    def removes_per_sec(self):
        """Gets the removes_per_sec of this ArrayNfsPerformance.  # noqa: E501

        REMOVE requests processed per second.  # noqa: E501

        :return: The removes_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._removes_per_sec

    @removes_per_sec.setter
    def removes_per_sec(self, removes_per_sec):
        """Sets the removes_per_sec of this ArrayNfsPerformance.

        REMOVE requests processed per second.  # noqa: E501

        :param removes_per_sec: The removes_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if removes_per_sec is not None and removes_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `removes_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._removes_per_sec = removes_per_sec

    @property
    def renames_per_sec(self):
        """Gets the renames_per_sec of this ArrayNfsPerformance.  # noqa: E501

        RENAME requests processed per second.  # noqa: E501

        :return: The renames_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._renames_per_sec

    @renames_per_sec.setter
    def renames_per_sec(self, renames_per_sec):
        """Sets the renames_per_sec of this ArrayNfsPerformance.

        RENAME requests processed per second.  # noqa: E501

        :param renames_per_sec: The renames_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if renames_per_sec is not None and renames_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `renames_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._renames_per_sec = renames_per_sec

    @property
    def rmdirs_per_sec(self):
        """Gets the rmdirs_per_sec of this ArrayNfsPerformance.  # noqa: E501

        RMDIR requests processed per second.  # noqa: E501

        :return: The rmdirs_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._rmdirs_per_sec

    @rmdirs_per_sec.setter
    def rmdirs_per_sec(self, rmdirs_per_sec):
        """Sets the rmdirs_per_sec of this ArrayNfsPerformance.

        RMDIR requests processed per second.  # noqa: E501

        :param rmdirs_per_sec: The rmdirs_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if rmdirs_per_sec is not None and rmdirs_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `rmdirs_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._rmdirs_per_sec = rmdirs_per_sec

    @property
    def setattrs_per_sec(self):
        """Gets the setattrs_per_sec of this ArrayNfsPerformance.  # noqa: E501

        SETATTR requests processed per second.  # noqa: E501

        :return: The setattrs_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._setattrs_per_sec

    @setattrs_per_sec.setter
    def setattrs_per_sec(self, setattrs_per_sec):
        """Sets the setattrs_per_sec of this ArrayNfsPerformance.

        SETATTR requests processed per second.  # noqa: E501

        :param setattrs_per_sec: The setattrs_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if setattrs_per_sec is not None and setattrs_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `setattrs_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._setattrs_per_sec = setattrs_per_sec

    @property
    def symlinks_per_sec(self):
        """Gets the symlinks_per_sec of this ArrayNfsPerformance.  # noqa: E501

        SYMLINK requests processed per second.  # noqa: E501

        :return: The symlinks_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._symlinks_per_sec

    @symlinks_per_sec.setter
    def symlinks_per_sec(self, symlinks_per_sec):
        """Sets the symlinks_per_sec of this ArrayNfsPerformance.

        SYMLINK requests processed per second.  # noqa: E501

        :param symlinks_per_sec: The symlinks_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if symlinks_per_sec is not None and symlinks_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `symlinks_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._symlinks_per_sec = symlinks_per_sec

    @property
    def time(self):
        """Gets the time of this ArrayNfsPerformance.  # noqa: E501

        Sample time in milliseconds since UNIX epoch.  # noqa: E501

        :return: The time of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this ArrayNfsPerformance.

        Sample time in milliseconds since UNIX epoch.  # noqa: E501

        :param time: The time of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """

        self._time = time

    @property
    def writes_per_sec(self):
        """Gets the writes_per_sec of this ArrayNfsPerformance.  # noqa: E501

        WRITE requests processed per second.  # noqa: E501

        :return: The writes_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._writes_per_sec

    @writes_per_sec.setter
    def writes_per_sec(self, writes_per_sec):
        """Sets the writes_per_sec of this ArrayNfsPerformance.

        WRITE requests processed per second.  # noqa: E501

        :param writes_per_sec: The writes_per_sec of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if writes_per_sec is not None and writes_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `writes_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._writes_per_sec = writes_per_sec

    @property
    def usec_per_access_op(self):
        """Gets the usec_per_access_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process an ACCESS request.  # noqa: E501

        :return: The usec_per_access_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_access_op

    @usec_per_access_op.setter
    def usec_per_access_op(self, usec_per_access_op):
        """Sets the usec_per_access_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process an ACCESS request.  # noqa: E501

        :param usec_per_access_op: The usec_per_access_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_access_op is not None and usec_per_access_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_access_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_access_op = usec_per_access_op

    @property
    def usec_per_create_op(self):
        """Gets the usec_per_create_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a CREATE request.  # noqa: E501

        :return: The usec_per_create_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_create_op

    @usec_per_create_op.setter
    def usec_per_create_op(self, usec_per_create_op):
        """Sets the usec_per_create_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a CREATE request.  # noqa: E501

        :param usec_per_create_op: The usec_per_create_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_create_op is not None and usec_per_create_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_create_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_create_op = usec_per_create_op

    @property
    def usec_per_fsinfo_op(self):
        """Gets the usec_per_fsinfo_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process an FSINFO request.  # noqa: E501

        :return: The usec_per_fsinfo_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_fsinfo_op

    @usec_per_fsinfo_op.setter
    def usec_per_fsinfo_op(self, usec_per_fsinfo_op):
        """Sets the usec_per_fsinfo_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process an FSINFO request.  # noqa: E501

        :param usec_per_fsinfo_op: The usec_per_fsinfo_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_fsinfo_op is not None and usec_per_fsinfo_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_fsinfo_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_fsinfo_op = usec_per_fsinfo_op

    @property
    def usec_per_fsstat_op(self):
        """Gets the usec_per_fsstat_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process an FSSTAT request.  # noqa: E501

        :return: The usec_per_fsstat_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_fsstat_op

    @usec_per_fsstat_op.setter
    def usec_per_fsstat_op(self, usec_per_fsstat_op):
        """Sets the usec_per_fsstat_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process an FSSTAT request.  # noqa: E501

        :param usec_per_fsstat_op: The usec_per_fsstat_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_fsstat_op is not None and usec_per_fsstat_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_fsstat_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_fsstat_op = usec_per_fsstat_op

    @property
    def usec_per_getattr_op(self):
        """Gets the usec_per_getattr_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a GETATTR request.  # noqa: E501

        :return: The usec_per_getattr_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_getattr_op

    @usec_per_getattr_op.setter
    def usec_per_getattr_op(self, usec_per_getattr_op):
        """Sets the usec_per_getattr_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a GETATTR request.  # noqa: E501

        :param usec_per_getattr_op: The usec_per_getattr_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_getattr_op is not None and usec_per_getattr_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_getattr_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_getattr_op = usec_per_getattr_op

    @property
    def usec_per_link_op(self):
        """Gets the usec_per_link_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a LINK request.  # noqa: E501

        :return: The usec_per_link_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_link_op

    @usec_per_link_op.setter
    def usec_per_link_op(self, usec_per_link_op):
        """Sets the usec_per_link_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a LINK request.  # noqa: E501

        :param usec_per_link_op: The usec_per_link_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_link_op is not None and usec_per_link_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_link_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_link_op = usec_per_link_op

    @property
    def usec_per_lookup_op(self):
        """Gets the usec_per_lookup_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a LOOKUP request.  # noqa: E501

        :return: The usec_per_lookup_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_lookup_op

    @usec_per_lookup_op.setter
    def usec_per_lookup_op(self, usec_per_lookup_op):
        """Sets the usec_per_lookup_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a LOOKUP request.  # noqa: E501

        :param usec_per_lookup_op: The usec_per_lookup_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_lookup_op is not None and usec_per_lookup_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_lookup_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_lookup_op = usec_per_lookup_op

    @property
    def usec_per_mkdir_op(self):
        """Gets the usec_per_mkdir_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a MKDIR request.  # noqa: E501

        :return: The usec_per_mkdir_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_mkdir_op

    @usec_per_mkdir_op.setter
    def usec_per_mkdir_op(self, usec_per_mkdir_op):
        """Sets the usec_per_mkdir_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a MKDIR request.  # noqa: E501

        :param usec_per_mkdir_op: The usec_per_mkdir_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_mkdir_op is not None and usec_per_mkdir_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_mkdir_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_mkdir_op = usec_per_mkdir_op

    @property
    def usec_per_other_op(self):
        """Gets the usec_per_other_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process all other requests.  # noqa: E501

        :return: The usec_per_other_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_other_op

    @usec_per_other_op.setter
    def usec_per_other_op(self, usec_per_other_op):
        """Sets the usec_per_other_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process all other requests.  # noqa: E501

        :param usec_per_other_op: The usec_per_other_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_other_op is not None and usec_per_other_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_other_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_other_op = usec_per_other_op

    @property
    def usec_per_pathconf_op(self):
        """Gets the usec_per_pathconf_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a PATHCONF request.  # noqa: E501

        :return: The usec_per_pathconf_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_pathconf_op

    @usec_per_pathconf_op.setter
    def usec_per_pathconf_op(self, usec_per_pathconf_op):
        """Sets the usec_per_pathconf_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a PATHCONF request.  # noqa: E501

        :param usec_per_pathconf_op: The usec_per_pathconf_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_pathconf_op is not None and usec_per_pathconf_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_pathconf_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_pathconf_op = usec_per_pathconf_op

    @property
    def usec_per_read_op(self):
        """Gets the usec_per_read_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a READ request.  # noqa: E501

        :return: The usec_per_read_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_read_op

    @usec_per_read_op.setter
    def usec_per_read_op(self, usec_per_read_op):
        """Sets the usec_per_read_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a READ request.  # noqa: E501

        :param usec_per_read_op: The usec_per_read_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_read_op is not None and usec_per_read_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_read_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_read_op = usec_per_read_op

    @property
    def usec_per_readdir_op(self):
        """Gets the usec_per_readdir_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a READDIR request.  # noqa: E501

        :return: The usec_per_readdir_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_readdir_op

    @usec_per_readdir_op.setter
    def usec_per_readdir_op(self, usec_per_readdir_op):
        """Sets the usec_per_readdir_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a READDIR request.  # noqa: E501

        :param usec_per_readdir_op: The usec_per_readdir_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_readdir_op is not None and usec_per_readdir_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_readdir_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_readdir_op = usec_per_readdir_op

    @property
    def usec_per_readdirplus_op(self):
        """Gets the usec_per_readdirplus_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a READDIRPLUS request.  # noqa: E501

        :return: The usec_per_readdirplus_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_readdirplus_op

    @usec_per_readdirplus_op.setter
    def usec_per_readdirplus_op(self, usec_per_readdirplus_op):
        """Sets the usec_per_readdirplus_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a READDIRPLUS request.  # noqa: E501

        :param usec_per_readdirplus_op: The usec_per_readdirplus_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_readdirplus_op is not None and usec_per_readdirplus_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_readdirplus_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_readdirplus_op = usec_per_readdirplus_op

    @property
    def usec_per_readlink_op(self):
        """Gets the usec_per_readlink_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a READLINK request.  # noqa: E501

        :return: The usec_per_readlink_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_readlink_op

    @usec_per_readlink_op.setter
    def usec_per_readlink_op(self, usec_per_readlink_op):
        """Sets the usec_per_readlink_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a READLINK request.  # noqa: E501

        :param usec_per_readlink_op: The usec_per_readlink_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_readlink_op is not None and usec_per_readlink_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_readlink_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_readlink_op = usec_per_readlink_op

    @property
    def usec_per_remove_op(self):
        """Gets the usec_per_remove_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a REMOVE request.  # noqa: E501

        :return: The usec_per_remove_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_remove_op

    @usec_per_remove_op.setter
    def usec_per_remove_op(self, usec_per_remove_op):
        """Sets the usec_per_remove_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a REMOVE request.  # noqa: E501

        :param usec_per_remove_op: The usec_per_remove_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_remove_op is not None and usec_per_remove_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_remove_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_remove_op = usec_per_remove_op

    @property
    def usec_per_rename_op(self):
        """Gets the usec_per_rename_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a RENAME request.  # noqa: E501

        :return: The usec_per_rename_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_rename_op

    @usec_per_rename_op.setter
    def usec_per_rename_op(self, usec_per_rename_op):
        """Sets the usec_per_rename_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a RENAME request.  # noqa: E501

        :param usec_per_rename_op: The usec_per_rename_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_rename_op is not None and usec_per_rename_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_rename_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_rename_op = usec_per_rename_op

    @property
    def usec_per_rmdir_op(self):
        """Gets the usec_per_rmdir_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process an RMDIR request.  # noqa: E501

        :return: The usec_per_rmdir_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_rmdir_op

    @usec_per_rmdir_op.setter
    def usec_per_rmdir_op(self, usec_per_rmdir_op):
        """Sets the usec_per_rmdir_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process an RMDIR request.  # noqa: E501

        :param usec_per_rmdir_op: The usec_per_rmdir_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_rmdir_op is not None and usec_per_rmdir_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_rmdir_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_rmdir_op = usec_per_rmdir_op

    @property
    def usec_per_setattr_op(self):
        """Gets the usec_per_setattr_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a SETATTR request.  # noqa: E501

        :return: The usec_per_setattr_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_setattr_op

    @usec_per_setattr_op.setter
    def usec_per_setattr_op(self, usec_per_setattr_op):
        """Sets the usec_per_setattr_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a SETATTR request.  # noqa: E501

        :param usec_per_setattr_op: The usec_per_setattr_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_setattr_op is not None and usec_per_setattr_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_setattr_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_setattr_op = usec_per_setattr_op

    @property
    def usec_per_symlink_op(self):
        """Gets the usec_per_symlink_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a SYMLINK request.  # noqa: E501

        :return: The usec_per_symlink_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_symlink_op

    @usec_per_symlink_op.setter
    def usec_per_symlink_op(self, usec_per_symlink_op):
        """Sets the usec_per_symlink_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a SYMLINK request.  # noqa: E501

        :param usec_per_symlink_op: The usec_per_symlink_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_symlink_op is not None and usec_per_symlink_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_symlink_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_symlink_op = usec_per_symlink_op

    @property
    def usec_per_write_op(self):
        """Gets the usec_per_write_op of this ArrayNfsPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a WRITE request.  # noqa: E501

        :return: The usec_per_write_op of this ArrayNfsPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_write_op

    @usec_per_write_op.setter
    def usec_per_write_op(self, usec_per_write_op):
        """Sets the usec_per_write_op of this ArrayNfsPerformance.

        Average time, measured in microseconds, it takes the array to process a WRITE request.  # noqa: E501

        :param usec_per_write_op: The usec_per_write_op of this ArrayNfsPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_write_op is not None and usec_per_write_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_write_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_write_op = usec_per_write_op

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ArrayNfsPerformance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArrayNfsPerformance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.1 Python SDK

    Pure Storage FlashBlade REST 1.1 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.1
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .error_response import ErrorResponse
from .file_system import FileSystem
from .file_system_response import FileSystemResponse
from .file_system_snapshot import FileSystemSnapshot
from .file_system_snapshot_response import FileSystemSnapshotResponse
from .login_response import LoginResponse
from .nfs_rule import NfsRule
from .object_response import ObjectResponse
from .pagination_info import PaginationInfo
from .protocol_rule import ProtocolRule
from .pure_error import PureError
from .pure_object import PureObject
from .snapshot_suffix import SnapshotSuffix
from .space import Space
from .version_response import VersionResponse



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.5 Python SDK

    Pure Storage FlashBlade REST 1.5 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.5
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PureArray(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'id': 'str',
        'ntp_servers': 'list[str]',
        'os': 'str',
        'revision': 'str',
        'time_zone': 'str',
        'version': 'str'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'ntp_servers': 'ntp_servers',
        'os': 'os',
        'revision': 'revision',
        'time_zone': 'time_zone',
        'version': 'version'
    }

    def __init__(self, name=None, id=None, ntp_servers=None, os=None, revision=None, time_zone=None, version=None):  # noqa: E501
        """PureArray - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._id = None
        self._ntp_servers = None
        self._os = None
        self._revision = None
        self._time_zone = None
        self._version = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if ntp_servers is not None:
            self.ntp_servers = ntp_servers
        if os is not None:
            self.os = os
        if revision is not None:
            self.revision = revision
        if time_zone is not None:
            self.time_zone = time_zone
        if version is not None:
            self.version = version

    @property
    def name(self):
        """Gets the name of this PureArray.  # noqa: E501

        The name of the object  # noqa: E501

        :return: The name of this PureArray.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PureArray.

        The name of the object  # noqa: E501

        :param name: The name of this PureArray.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this PureArray.  # noqa: E501

        A globally unique ID chosen by the system. Cannot change. Cannot ever refer to another resource.  # noqa: E501

        :return: The id of this PureArray.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PureArray.

        A globally unique ID chosen by the system. Cannot change. Cannot ever refer to another resource.  # noqa: E501

        :param id: The id of this PureArray.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ntp_servers(self):
        """Gets the ntp_servers of this PureArray.  # noqa: E501


        :return: The ntp_servers of this PureArray.  # noqa: E501
        :rtype: list[str]
        """
        return self._ntp_servers

    @ntp_servers.setter
    def ntp_servers(self, ntp_servers):
        """Sets the ntp_servers of this PureArray.


        :param ntp_servers: The ntp_servers of this PureArray.  # noqa: E501
        :type: list[str]
        """

        self._ntp_servers = ntp_servers

    @property
    def os(self):
        """Gets the os of this PureArray.  # noqa: E501

        Possible values are Purity//FA and Purity//FB.  # noqa: E501

        :return: The os of this PureArray.  # noqa: E501
        :rtype: str
        """
        return self._os

    @os.setter
    def os(self, os):
        """Sets the os of this PureArray.

        Possible values are Purity//FA and Purity//FB.  # noqa: E501

        :param os: The os of this PureArray.  # noqa: E501
        :type: str
        """

        self._os = os

    @property
    def revision(self):
        """Gets the revision of this PureArray.  # noqa: E501


        :return: The revision of this PureArray.  # noqa: E501
        :rtype: str
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this PureArray.


        :param revision: The revision of this PureArray.  # noqa: E501
        :type: str
        """

        self._revision = revision

    @property
    def time_zone(self):
        """Gets the time_zone of this PureArray.  # noqa: E501


        :return: The time_zone of this PureArray.  # noqa: E501
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this PureArray.


        :param time_zone: The time_zone of this PureArray.  # noqa: E501
        :type: str
        """

        self._time_zone = time_zone

    @property
    def version(self):
        """Gets the version of this PureArray.  # noqa: E501


        :return: The version of this PureArray.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PureArray.


        :param version: The version of this PureArray.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PureArray, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PureArray):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.8.1 Python SDK

    Pure Storage FlashBlade REST 1.8.1 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.8.1
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class QuotasGroup(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'file_system': 'FixedReference',
        'file_system_default_quota': 'int',
        'group': 'QuotasgroupGroup',
        'quota': 'int',
        'usage': 'int'
    }

    attribute_map = {
        'name': 'name',
        'file_system': 'file_system',
        'file_system_default_quota': 'file_system_default_quota',
        'group': 'group',
        'quota': 'quota',
        'usage': 'usage'
    }

    def __init__(self, name=None, file_system=None, file_system_default_quota=None, group=None, quota=None, usage=None):  # noqa: E501
        """QuotasGroup - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._file_system = None
        self._file_system_default_quota = None
        self._group = None
        self._quota = None
        self._usage = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if file_system is not None:
            self.file_system = file_system
        if file_system_default_quota is not None:
            self.file_system_default_quota = file_system_default_quota
        if group is not None:
            self.group = group
        if quota is not None:
            self.quota = quota
        if usage is not None:
            self.usage = usage

    @property
    def name(self):
        """Gets the name of this QuotasGroup.  # noqa: E501

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :return: The name of this QuotasGroup.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this QuotasGroup.

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :param name: The name of this QuotasGroup.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def file_system(self):
        """Gets the file_system of this QuotasGroup.  # noqa: E501


        :return: The file_system of this QuotasGroup.  # noqa: E501
        :rtype: FixedReference
        """
        return self._file_system

    @file_system.setter
    def file_system(self, file_system):
        """Sets the file_system of this QuotasGroup.


        :param file_system: The file_system of this QuotasGroup.  # noqa: E501
        :type: FixedReference
        """

        self._file_system = file_system

    @property
    def file_system_default_quota(self):
        """Gets the file_system_default_quota of this QuotasGroup.  # noqa: E501

        File system's default group quota (in bytes). If it is 0, it means there is no default quota. This will be the effective group quota if the group doesn't have an individual quota. This default quota is set through the file-system endpoint.  # noqa: E501

        :return: The file_system_default_quota of this QuotasGroup.  # noqa: E501
        :rtype: int
        """
        return self._file_system_default_quota

    @file_system_default_quota.setter
    def file_system_default_quota(self, file_system_default_quota):
        """Sets the file_system_default_quota of this QuotasGroup.

        File system's default group quota (in bytes). If it is 0, it means there is no default quota. This will be the effective group quota if the group doesn't have an individual quota. This default quota is set through the file-system endpoint.  # noqa: E501

        :param file_system_default_quota: The file_system_default_quota of this QuotasGroup.  # noqa: E501
        :type: int
        """

        self._file_system_default_quota = file_system_default_quota

    @property
    def group(self):
        """Gets the group of this QuotasGroup.  # noqa: E501


        :return: The group of this QuotasGroup.  # noqa: E501
        :rtype: QuotasgroupGroup
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this QuotasGroup.


        :param group: The group of this QuotasGroup.  # noqa: E501
        :type: QuotasgroupGroup
        """

        self._group = group

    @property
    def quota(self):
        """Gets the quota of this QuotasGroup.  # noqa: E501

        The space limit of the quota (in bytes) for the specified group, cannot be 0. Modifiable. If specified, this value will override the file system's default group quota.  # noqa: E501

        :return: The quota of this QuotasGroup.  # noqa: E501
        :rtype: int
        """
        return self._quota

    @quota.setter
    def quota(self, quota):
        """Sets the quota of this QuotasGroup.

        The space limit of the quota (in bytes) for the specified group, cannot be 0. Modifiable. If specified, this value will override the file system's default group quota.  # noqa: E501

        :param quota: The quota of this QuotasGroup.  # noqa: E501
        :type: int
        """

        self._quota = quota

    @property
    def usage(self):
        """Gets the usage of this QuotasGroup.  # noqa: E501

        The usage of the file system (in bytes) by the specified group.  # noqa: E501

        :return: The usage of this QuotasGroup.  # noqa: E501
        :rtype: int
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        """Sets the usage of this QuotasGroup.

        The usage of the file system (in bytes) by the specified group.  # noqa: E501

        :param usage: The usage of this QuotasGroup.  # noqa: E501
        :type: int
        """

        self._usage = usage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QuotasGroup, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QuotasGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
